Compute Local Redundancy for Each Searchlight Center
Source:R/permutation_searchlight.R
compute_local_redundancy.RdFor each searchlight sphere, computes the mean absolute correlation between the center voxel (first column of the extracted data matrix) and all other voxels in the sphere. This serves as an autocorrelation proxy that can be used as a covariate when building the null distribution.