Convenience wrapper around crossval_samples for use inside
fit_roi methods. Separates fold generation from the
iteration engine so that models can generate folds directly.
Convenience wrapper around crossval_samples for use inside
fit_roi methods. Separates fold generation from the
iteration engine so that models can generate folds directly.