Creates a lightweight configuration object for the supported high-level
workflow API. Config values can be supplied directly as named arguments or
loaded from a YAML or R config file via config.
Usage
mvpa_config(mode = c("searchlight", "regional", "global"), config = NULL, ...)