Extract per-item distances between memory and perception prototypes in the jointly-whitened space, before (naive) and after the REMAP correction. Works from a `regional_mvpa_result` when `return_fits=TRUE`, or directly from a predictor list returned by `process_roi()`.
Examples
if (FALSE) { # \dontrun{
res <- run_regional(model, region_mask, return_fits = TRUE)
items_tbl <- summarize_remap_items(res, roi = 1)
} # }