This function constructs a design for an RSA model using a single distance matrix, labels, and blocks.
Value
A list containing the elements of the RSA design, class attributes "vector_rsa_design" and "list".
This function constructs a design for an RSA model using a single distance matrix, labels, and blocks.
A list containing the elements of the RSA design, class attributes "vector_rsa_design" and "list".